# DeepPhysX_Sofa

This python package is part of the [DeepPhysX](https://github.com/mimesis-inria/DeepPhysX) project.
It contains adaptations of some Core components that are compatible with the [SOFA](https://www.sofa-framework.org/) 
framework.

### Installation

Cloning the main package is of course mandatory:

```bash
$ git clone https://github.com/mimesis-inria/DeepPhysX.git
```

This repository is automatically cloned when configuring the [DeepPhysX](https://github.com/mimesis-inria/DeepPhysX) 
installation.
Otherwise, it can also be cloned manually in a `Sofa` directory:

```bash
$ cd DeepPhysX
$ git clone https://github.com/mimesis-inria/DeepPhysX_Sofa.git Sofa
```

This package will be automatically detected when configuring the project installation.
